package com.emr.service.BatchApplyDetails;

import com.emr.dto.FastBorrowingDto;
import com.emr.entity.BatchApplyDetails;
import com.emr.vo.BatchBorrowingVo;
import com.emr.vo.Msg;
import com.emr.vo.commomSearch.CommomVo;

import java.util.List;

/**
 * @InterfaceName BatchApplyService
 * @Description 批量借阅接口
 * @Author linjj
 * @Date 2023/8/28 17:10
 * @Version 1.0
 */
public interface BatchApplyDetailsService {



     List<CommomVo> addCommomVo(CommomVo commomVo) throws Exception;

     List<BatchApplyDetails> getBatchApplyDetails(int batchId,String inpatientNo);

     Msg addBatchBorrowing(BatchBorrowingVo batchBorrowingVo);

     int deleteById(int id,int batchId);

     int rejectById(int id);

     int agreeById(String ids,Integer batchId);

     int updateReturn(String barCode,String barCodeName);

     Msg addFastBorrowing(FastBorrowingDto dto);

     Msg updateBatchApply(String barCode,String barCodeName,int batchId);

     Msg fastBatchApply(FastBorrowingDto dto);
}
